%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Generate Impulse Response
% 20 December 2006, Release 1.0
%
% Comment: This function applies the spatial filtering, does the discrete
% time to continuous time conversion, and then generates the actual complex baseband impulse
% responses to be used for proposal analysis.
%
% Input:
%
% Output:
%
% Internal Variables:
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp(' ')
disp('--> Running Generate Impulse Response')
disp(' This routine generates a complex baseband impulse response')

% load required MAT files
load ChanNum
cd(strcat('CM',num2str(ChanNum)))
load FullVectors
load ImpInfoStuff % loaded variables are NumChannels, NumClusters, NumRays, NumRaysPerCluster, t0[1,100]
load SortedVectors
load FullValues
cd ..

% input the sample rate
SampFreq = input(' Input Sample Frequency (Gsps): ');
SampFreq=SampFreq*1e9;
ts = 1/SampFreq;  % sampling frequency

% input the antenna beam width

ABW_select = input(' Use applicable TSV default antenna beamwidths (1) or select your own beamwidth (2)? ');
if ABW_select==1
    if ChanNum==1.1 || ChanNum==2.1
        AntBeamWidth=15; % default
    elseif ChanNum==1.2 || ChanNum==2.2
        AntBeamWidth=15; % default
    elseif ChanNum==1.3 || ChanNum==2.3
        AntBeamWidth=15; % default
    elseif ChanNum==1.4 || ChanNum==2.4
        AntBeamWidth=15; % default
    elseif ChanNum==1.5 || ChanNum==2.5
        AntBeamWidth=15; % default
    elseif ChanNum==3.1
        AntBeamWidth=30; % default
    elseif ChanNum==3.2
        AntBeamWidth=60; % default
    elseif ChanNum==4.1
        AntBeamWidth=15; % default
    elseif ChanNum==4.2
        AntBeamWidth=15; % default
    elseif ChanNum==4.3
        AntBeamWidth=15; % default
    elseif ChanNum==9.1
        AntBeamWidth=30; % default
    elseif ChanNum==9.2
        AntBeamWidth=60; % default
    elseif ChanNum==9.3
        AntBeamWidth=15; % default
    else
        AntBeamWidth = -1;
        while (AntBeamWidth>360 || AntBeamWidth<1)
            AntBeamWidth = input(' Input Antenna Beam Width: [1 to 360 degs]: ');
        end
    end
else
    AntBeamWidth = -1;
    while (AntBeamWidth>360 || AntBeamWidth<1)
        AntBeamWidth = input(' Input Antenna Beam Width: [1 to 360 degs]: ');
    end
end

if AntBeamWidth>359
    Omni=1; % if >359 then assume it is just Omni-directional
    disp(strcat(' ...RX Antenna Beamwidth= ','omni-directional'))
else
    Omni=0;
    disp(strcat(' ...RX Antenna Beamwidth= ',num2str(AntBeamWidth),' degrees'))
end
AntBeamWidth=AntBeamWidth*pi/180; % convert to radians

AutoPointFlag=0; % initial a flag used later

if Omni==0 % auto antenna pointing only makes sense if not omni-directional
    % ask if Gaussian is desired
    GaussBeam = input(' Do you want "Gaussian Sidelobes" (1) or "Ideal" (2): ');

    % input the antenna pointing angle
    AntBeamAng = -181; AutoPointFlag=0;
    while (AntBeamAng>181 || AntBeamAng<-180)
        AntBeamAng = input(' Input Ant Point Ang: [-180 to 180 degs] - or - enter "181" for automatic pointing per realization: ');
    end
    if AntBeamAng==181
        AutoPointFlag=1;
    end
    AntBeamAng=AntBeamAng*pi/180; % convert to radians

    % Auto Antenna Pointing Routine
    if AutoPointFlag==1
        disp(' '); TrkQ=input('Do you want to track the strongest cluster [1] or strongest ray [2]? ');
        disp(' '); disp(' Running Auto Antenna Pointing Algorithm')
        MaxClusterVal=zeros(NumChannels,1);
        MaxClusterNum=zeros(NumChannels,1);
        MaxClusterAoA=zeros(NumChannels,1);
        if TrkQ==1
            % find the strongest cluster in each realization and the related AoA
            for ChanIndex=1:NumChannels
                [MaxVal(ChanIndex), MaxNum(ChanIndex)]=max(sum(InsPow(:,:,ChanIndex)));
                MaxAoA(ChanIndex)=mean(Aoa(:,MaxNum(ChanIndex),ChanIndex))-pi; % Aoa is between 0 and 2pi
            end
        else
            % find the strongest ray in each realization and the related AoA
            for ChanIndex=1:NumChannels
                [MaxVal(ChanIndex), MaxNum(ChanIndex)]=max(InsPowVector(:,ChanIndex));
                MaxAoA(ChanIndex)=AoaWrappedVector(MaxNum(ChanIndex),ChanIndex); % Aoa is between 0 and 2pi
            end
        end

        for index=1:NumChannels
            if MaxAoA(index)>pi
                MaxAoA(index)=MaxAoA(index)-2*pi; % correct for 2 PI wrap around, make between -pi and pi
            end
        end 
    end
end

% Generate complex continuous time impulse response
Phase = rand(size(SortedAmp));                       % Random phase
ImpCt = sqrt(SortedAmp) .* exp(2*pi*1i*Phase);       % Instantaneous impulse response

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% translate variables into a form usable by borrowed code fragments
TimeCt=SortedTime;
np=NumRays*ones(1,NumChannels); % generate "np" in a form usable by prior TG3a code 
Ang=SortedAng;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Ray Polar Plot Before Spatial Filtering
Circle=(-pi:0.01:pi);
radius=max(max(abs(ImpCt)));
figure(1)
hold on
for ChanIndex=1:NumChannels
    temp1=mod(ChanIndex,7);
    if temp1==1
        color='b';
    elseif temp1==2
        color='g';
    elseif temp1==3
        color='r';
    elseif temp1==4
        color='c';
    elseif temp1==5
        color='m';
    elseif temp1==6
        color='y';
    else
        color='k';
    end
    polar(Ang(:,ChanIndex),abs(ImpCt(:,ChanIndex)),color)
end
polar(Circle,radius*ones(size(Circle)),'k--')
title('Ray Polar Plot before Spatial Filtering')
hold off

%%%%%%%%%%%%% SPATIAL FILTERING - EXAMPLE IS DONE HERE %%%%%%%%%%%%%%%%%%%%

if Omni==0 % =0 means not omni-directional
    if GaussBeam==1 % Gaussian Beam Shape
        % prepare the Guassian Pattern
        alpha=4*log(2)/AntBeamWidth^2;
        % plot the pattern for inspection
        TestTheta=-180:180;
        PatdB=10*log10(exp(-alpha*(pi*TestTheta/180).^2));
        figure(101)
        plot(TestTheta,PatdB)
        title('Gaussian Antenna Pattern')
        xlabel('degrees')
        ylabel('dB')
        axis([-90 90 -20 0])
        grid on
        % now apply the spatial filter
        for cn=1:NumChannels
            for index=1:length(ImpCt(:,1))
                if AutoPointFlag==1
                    EqAng=Ang(index,cn)-MaxAoA(cn);
                    if EqAng>pi
                        EqAng=EqAng-2*pi;
                    elseif EqAng<-pi
                        EqAng=EqAng+2*pi;
                    end
                    SideLobe=sqrt(exp(-alpha*EqAng^2));
                    ImpCt(index,cn)=SideLobe*ImpCt(index,cn);
                else
                    EqAng=Ang(index,cn)-AntBeamAng;
                    temp1=EqAng;
                    if EqAng>pi
                        EqAng=EqAng-2*pi;
                    elseif EqAng<-pi
                        EqAng=EqAng+2*pi;
                    end
                    SideLobe=sqrt(exp(-alpha*EqAng^2));
                    temp2=EqAng;
                    ImpCt(index,cn)=SideLobe*ImpCt(index,cn);
                end
            end
        end
    else % NO SIDELOBES ... brickwall spatial pattern
        % prepare the spatial filter edges
        if AutoPointFlag==1
            RhEdge = (mod( MaxAoA - AntBeamWidth/2 + pi , 2*pi ) - pi); % auto pointing
            LhEdge = (mod( MaxAoA + AntBeamWidth/2 + pi , 2*pi ) - pi);
            figure(101)
            hold on
            plot(RhEdge,'r.'); plot(MaxAoA,'b.'); plot(LhEdge,'g.')
            title('Aiming Accuracy Plot ... green is top of beam, red is bottom of beam')
            xlabel('If pointing correctly, the blue dot should be midway between the red and green dots for each channel')
            ylabel('radians')
            grid on
            hold off
        else
            RhEdge = ones(NumChannels, 1) * (mod( AntBeamAng - AntBeamWidth/2 + pi , 2*pi ) - pi); % fixed pointing
            LhEdge = ones(NumChannels, 1) * (mod( AntBeamAng + AntBeamWidth/2 + pi , 2*pi ) - pi);
        end
        % now apply the spatial filter
        for cn=1:NumChannels
            for index=1:length(ImpCt(:,1))
                if (RhEdge(cn)-LhEdge(cn))<0
                    if ((Ang(index,cn)>LhEdge(cn)) || (Ang(index,cn)<RhEdge(cn))) % ant beam width about bore sight
                        ImpCt(index,cn)=0; % spatial filter
                    end
                else
                    if ((Ang(index,cn)>LhEdge(cn)) && (Ang(index,cn)<RhEdge(cn))) % ant beam width about bore sight
                        ImpCt(index,cn)=0; % spatial filter
                    end
                end
            end
        end
    end
end

% Ray Polar Plot After Spatial Filtering
figure(2)
hold on
for ChanIndex=1:NumChannels
    temp1=mod(ChanIndex,7);
    if temp1==1
        color='b';
    elseif temp1==2
        color='g';
    elseif temp1==3
        color='r';
    elseif temp1==4
        color='c';
    elseif temp1==5
        color='m';
    elseif temp1==6
        color='y';
    else
        color='k';
    end
    polar(Ang(:,ChanIndex),abs(ImpCt(:,ChanIndex)),color)
end
if AutoPointFlag==0 && Omni==0
    polar([AntBeamWidth/2+AntBeamAng AntBeamWidth/2+AntBeamAng],[radius 0],'r--')
    polar([-AntBeamWidth/2+AntBeamAng -AntBeamWidth/2+AntBeamAng],[radius 0],'r--')
end
polar(Circle,radius*ones(size(Circle)),'k--')
title('Ray Polar Plot after Spatial Filtering')
hold off

% now reduce continuous-time result to a discrete-time result
[ImpDt] = ct2dt( ImpCt, TimeCt, NumChannels, ts );

% normalize the energy in each realization to a value of 1
SpatialFilteredEnergy=zeros(NumChannels,1);
NothingLeft=zeros(NumChannels,1);
for ChanIndex=1:NumChannels
    SpatialFilteredEnergy(ChanIndex)=sum(abs(ImpDt(:,ChanIndex)).^2);
    if SpatialFilteredEnergy(ChanIndex)~=0
        ImpDt(:,ChanIndex)=ImpDt(:,ChanIndex)/sqrt(sum(abs(ImpDt(:,ChanIndex)).^2));
    else
        NothingLeft(ChanIndex)=1;
    end
end

% check to see if there is any energy left to form the impulse response
if sum(NothingLeft)==NumChannels
    beep; disp(' ')
    disp('SORRY - YOU SPATIALLY FILTERED OUT EVERYTHING!')
    disp('THERE IS NO SIGNAL LEFT IN ANY REALIZATION!')
    disp('TERMINATING NOW - BYE')
    load xgong
    p=audioplayer(y, Fs);
    play(p)
    cd(strcat('CM',num2str(ChanNum)))
    delete IR_real.xls 
    delete IR_imag.xls
    delete ImpResp.mat
    cd ..
    return
end

[Nrows,Ncols]=size(ImpDt); % number of rows "Nrows" indicates length of impulse response
% truncate impulse response to the -40 dB point
index_max=zeros(NumChannels,1);
z_max=max(max(abs(ImpDt)));
for index_cn=1:NumChannels
    IM_done=0;
    for index=Nrows:-1:1 % work backwards thru vector
        if IM_done==0
            if abs(ImpDt(index,index_cn))>z_max/1e2
                index_max(index_cn)=index; % search for largest index that gives -40 dB
                IM_done=1;
            end
        end
    end
end
ImpDtTrunc=ImpDt(1:max(index_max),:); % truncate by using the largest index

% generate the Discrete Time base vectors
h_len = length(ImpDtTrunc(:,1));
if h_len>1
    TimeDt = (0:(h_len-1)) * ts;  % for use in computing excess & RMS delays
else
    TimeDt = ts; % single point in the impulse response
end

% save off the vectors of interest
cd(strcat('CM',num2str(ChanNum)))
save ImpResp ImpDtTrunc TimeDt t0 NumChannels NothingLeft
cd ..

%********************************************************************
% Testing and ploting of Channel Metrics
%********************************************************************

% channel energy
kk=0;
for ChanIndex=1:NumChannels
    if NothingLeft(ChanIndex)==0
        kk=kk+1; % artifical counter so nulled channels don't matter
        [Row,Col]=size(ImpDtTrunc);
        if Row>1
            channel_energy(kk) = sum(abs(ImpDtTrunc(:,ChanIndex)).^2); 
        else
            channel_energy(kk) = abs(ImpDtTrunc(ChanIndex)).^2; 
        end
    end
end

% calculate metrics
excess_delay = zeros(1,NumChannels);
RMS_delay = zeros(1,NumChannels);
num_sig_paths = zeros(1,NumChannels);
num_sig_e_paths = zeros(1,NumChannels);

kk=0;
for k=1:NumChannels
    if NothingLeft(k)==0
       kk=kk+1; % artifical counter so nulled channels don't matter
       % determine excess delay and RMS delay
       sq_h = abs(ImpDtTrunc(:,k)).^2 / channel_energy(kk);
       t_norm = TimeDt - t0(k);  % remove the randomized arrival time of first cluster
       excess_delay(kk) = t_norm * sq_h;
       RMS_delay(kk) = sqrt( ((t_norm-excess_delay(kk)).^2) * sq_h );

       % determine number of significant paths (paths within 10 dB from peak)
       threshold_dB = -10;   % dB
       temp_h = abs(ImpDtTrunc(:,k));
       temp_thresh = 10^(threshold_dB/20) * max(temp_h);
       num_sig_paths(kk) = sum(temp_h > temp_thresh);

       % determine number of sig. paths (captures x % of energy in channel)
       x = 0.85;
       temp_sort = sort(temp_h.^2);  % sorted in ascending order of energy
       cum_energy = cumsum(temp_sort(end:-1:1));  % cumulative energy
       index_e = min(find(cum_energy >= x * cum_energy(end)));
       num_sig_e_paths(kk) = index_e;
    end
end

energy_mean = mean(10*log10(channel_energy));
energy_stddev = std(10*log10(channel_energy));
mean_excess_delay = mean(excess_delay);
mean_RMS_delay = mean(RMS_delay);
mean_sig_paths = mean(num_sig_paths);
mean_sig_e_paths = mean(num_sig_e_paths);

% print this to the screen
disp(' '); fprintf(1,'Model Characteristics\n');
fprintf(1,'  Mean delays: excess (tau_m) = %1.2f ns, RMS (tau_rms) = %1.2f ns\n', ...
    1e9*mean_excess_delay, 1e9*mean_RMS_delay);
fprintf(1,'  # paths: NP_10dB =  %.1f, NP_85%% = %.1f\n', ...
    mean_sig_paths, mean_sig_e_paths);
fprintf(1,'  Channel energy: mean = %.1f dB, std deviation = %.1f dB\n', ...
  energy_mean, energy_stddev);
fprintf(1,'  Channels Spatially Nulled: %.1f , Remaining Channels: %.1f\n', ...
  sum(NothingLeft), NumChannels-sum(NothingLeft));

% plot out the statistics
figure(3)
MaxImp=max(max(abs(ImpDtTrunc)));
plot(TimeDt,20*log10(1e-2+abs(ImpDtTrunc/MaxImp))); grid on % limit the lower log value
axis tight
title('Impulse Response dB Magnitude')
xlabel('nS')
ylabel('dB')

figure(4)
subplot(2,1,1); plot(TimeDt,real(ImpDtTrunc)); title('real impulse response'); grid on
subplot(2,1,2); plot(TimeDt,imag(ImpDtTrunc)); title('imag impulse response'); grid on
xlabel('nS')

figure(5); clf; plot(1:NumChannels, excess_delay, 'b-', ...
  [1 NumChannels], mean_excess_delay*[1 1], 'r--' );
grid on
title('Excess delay (nS)')
xlabel('Channel number')

figure(6); clf; plot(1:NumChannels, RMS_delay, 'b-', ...
  [1 NumChannels], mean_RMS_delay*[1 1], 'r--' );
grid on
title('RMS delay (nS)')
xlabel('Channel number')

figure(7); clf; plot(1:NumChannels, num_sig_paths, 'b-', ...
  [1 NumChannels], mean_sig_paths*[1 1], 'r--');
grid on
title('Number of significant paths within 10 dB of peak')
xlabel('Channel number')

figure(8); clf; plot(1:NumChannels, num_sig_e_paths, 'b-', ...
  [1 NumChannels], mean_sig_e_paths*[1 1], 'r--');
grid on
title('Number of significant paths capturing > 85% energy')
xlabel('Channel number')

temp_average_power = sum((abs(ImpDtTrunc))'.*(abs(ImpDtTrunc))')/NumChannels;
temp_average_power = temp_average_power/max(temp_average_power);
average_decay_profile_dB = 10*log10(temp_average_power+1e-20);
figure(9); clf; plot(TimeDt,average_decay_profile_dB); grid on
axis([0 TimeDt(end) -60 0])
title('Average Power Decay Profile')
xlabel('Delay (nsec)')
ylabel('Average power (dB)')

figure(10)
stem(NothingLeft,'.')
title('Nulled Channels due to Spatial Filtering')
xlabel('Channel Number')
ylabel('Nulled Channel')
grid on

% store off the impulse responses in ASCII format
IR_real=[TimeDt' real(ImpDtTrunc)];
IR_imag=[TimeDt' imag(ImpDtTrunc)];

disp(' ')
disp(strcat('Writing ASCII files IR_real.xls and IR_imag.xls to directory CM',num2str(ChanNum)))

cd(strcat('CM',num2str(ChanNum)))
save IR_real.xls IR_real -ASCII -TABS
save IR_imag.xls IR_imag -ASCII -TABS
cd ..

return; % end of program
