%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
%
% Load S-V Parameters
% 20 December 2006, Release 1.0
%
% Loads the modified S-V model parameters for TG3c channel models
%--------------------------------------------------------------------------
% n                 Path Loss Exponent
% PLo               Free Space Path Loss at Reference Distance 
% LowSigma_s        Standard Deviation of Path Loss Shadowing
% CapLambda         Cluster arrival rate (clusters per nsec)
% LowLambda         Ray arrival rate (rays per nsec)
% CapGamma          Cluster Decay Factor
% LowGamma          Ray Decay Factor
% LowSigma_c        Standard Deviation of Cluster Lognormal Fading Term (dB)
% LowSigma_r        Standard Deviation of Ray Lognormal Fading Term (dB)
% LowSignma_phi     Standard Deviation of the Ray Angle of Arrival
% L_mean            Mean number of Clusters
% Delta_CapK        LOS Rician Factor
% Delta_LowK        Cluster First Ray Factor
% nlos              Flag for non line of sight channel
%                       0 -> LOS
%                       1 -> NLOS
% TSV_flag          Flag for non line of sight channel
%                       0 -> Regualr LOS
%                       1 -> TSV LOS
% SynNLOS           Flag for non line of sight channel
%                       0 -> Regular NLOS
%                       1 -> Synthesize NLOS from LOS model
%
% Input:
%
% Output:
%
% Internal Variables:
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% ParamStore definition:
%
% ParamStore(cm_num, ... 17 S-V parameters ...)
%
% dimensions: ParamStore (17, 17)
%
% ParamStore(cm_num, 1) <-- n
% ParamStore(cm_num, 2) <-- PLo
% ParamStore(cm_num, 3) <-- LowSigma_s
% ParamStore(cm_num, 4) <-- CapLambda
% ParamStore(cm_num, 5) <-- LowLambda
% ParamStore(cm_num, 6) <-- CapGamma
% ParamStore(cm_num, 7) <-- LowGamma
% ParamStore(cm_num, 8) <-- LowSigma_c
% ParamStore(cm_num, 9) <-- LowSigma_r
% ParamStore(cm_num, 10) <-- LowSigma_phi
% ParamStore(cm_num, 11) <-- L_mean
% ParamStore(cm_num, 12) <-- Delta_CapK
% ParamStore(cm_num, 13) <-- Delta_LowK
% ParamStore(cm_num, 14) <-- nlos
% ParamStore(cm_num, 15) <-- TSV_flag
% ParamStore(cm_num, 16) <-- SynNLOS
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

cm_num=1.1; % Residential LOS
  ParamStore(10*cm_num, 1)= 1.53; % n
  ParamStore(10*cm_num, 2)= 75.1; % PLo
  ParamStore(10*cm_num, 3)= 1.5; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1/5.24; % CapLambda
  ParamStore(10*cm_num, 5)= 1/0.82; % LowLambda
  ParamStore(10*cm_num, 6)= 4.46; % CapGamma
  ParamStore(10*cm_num, 7)= 6.25; % LowGamma
  ParamStore(10*cm_num, 8)= 6.28; % LowSigma_c
  ParamStore(10*cm_num, 9)= 13.0; % LowSigma_r
  ParamStore(10*cm_num, 10)= 49.8; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 9; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -18.8; % Delta_LowK
  ParamStore(10*cm_num, 14)= 0; %nlos
  ParamStore(10*cm_num, 15)= 1; % TSV flag
  ParamStore(10*cm_num, 16)= 0; % SynNLOS
cm_num=1.2; % Residential LOS
  ParamStore(10*cm_num, 1)= 1.53; % n
  ParamStore(10*cm_num, 2)= 75.1; % PLo
  ParamStore(10*cm_num, 3)= 1.5; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1/5.15; % CapLambda
  ParamStore(10*cm_num, 5)= 1/1.11; % LowLambda
  ParamStore(10*cm_num, 6)= 8.98; % CapGamma
  ParamStore(10*cm_num, 7)= 9.17; % LowGamma
  ParamStore(10*cm_num, 8)= 6.63; % LowSigma_c
  ParamStore(10*cm_num, 9)= 9.83; % LowSigma_r
  ParamStore(10*cm_num, 10)= 119; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 11; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -17.4; % Delta_LowK
  ParamStore(10*cm_num, 14)= 0; %nlos
  ParamStore(10*cm_num, 15)= 1; % TSV flag
  ParamStore(10*cm_num, 16)= 0; % SynNLOS
cm_num=1.3; % Residential LOS
  ParamStore(10*cm_num, 1)= 1.53; % n
  ParamStore(10*cm_num, 2)= 75.1; % PLo
  ParamStore(10*cm_num, 3)= 1.5; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1/6.94; % CapLambda
  ParamStore(10*cm_num, 5)= 1/0.856; % LowLambda
  ParamStore(10*cm_num, 6)= 21.5; % CapGamma
  ParamStore(10*cm_num, 7)= 4.35; % LowGamma
  ParamStore(10*cm_num, 8)= 3.71; % LowSigma_c
  ParamStore(10*cm_num, 9)= 7.31; % LowSigma_r
  ParamStore(10*cm_num, 10)= 46.2; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 8; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -11.9; % Delta_LowK
  ParamStore(10*cm_num, 14)= 0; %nlos
  ParamStore(10*cm_num, 15)= 1; % TSV flag
  ParamStore(10*cm_num, 16)= 0; % SynNLOS
cm_num=1.4; % Residential LOS
  ParamStore(10*cm_num, 1)= 1.53; % n
  ParamStore(10*cm_num, 2)= 75.1; % PLo
  ParamStore(10*cm_num, 3)= 1.5; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1/22.2; % CapLambda
  ParamStore(10*cm_num, 5)= 1/1.08; % LowLambda
  ParamStore(10*cm_num, 6)= 12.6; % CapGamma
  ParamStore(10*cm_num, 7)= 4.98; % LowGamma
  ParamStore(10*cm_num, 8)= 7.34; % LowSigma_c
  ParamStore(10*cm_num, 9)= 6.11; % LowSigma_r
  ParamStore(10*cm_num, 10)= 107; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 4; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -4.60; % Delta_LowK
  ParamStore(10*cm_num, 14)= 0; %nlos
  ParamStore(10*cm_num, 15)= 1; % TSV flag
  ParamStore(10*cm_num, 16)= 0; % SynNLOS
cm_num=1.5; % Residential LOS
  ParamStore(10*cm_num, 1)= 1.53; % n
  ParamStore(10*cm_num, 2)= 75.1; % PLo
  ParamStore(10*cm_num, 3)= 1.5; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1/4.76; % CapLambda
  ParamStore(10*cm_num, 5)= 1/1.30; % LowLambda
  ParamStore(10*cm_num, 6)= 4.19; % CapGamma
  ParamStore(10*cm_num, 7)= 1.07; % LowGamma
  ParamStore(10*cm_num, 8)= 1.54; % LowSigma_c
  ParamStore(10*cm_num, 9)= 1.26; % LowSigma_r
  ParamStore(10*cm_num, 10)= 8.32; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 4; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -10; % Delta_LowK
  ParamStore(10*cm_num, 14)= 0; %nlos
  ParamStore(10*cm_num, 15)= 0; % TSV flag
  ParamStore(10*cm_num, 16)= 0; % SynNLOS
cm_num=2.1; % Residential NLOS
  ParamStore(10*cm_num, 1)= 1.53; % n
  ParamStore(10*cm_num, 2)= 75.1; % PLo
  ParamStore(10*cm_num, 3)= 1.5; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1/5.24; % CapLambda
  ParamStore(10*cm_num, 5)= 1/0.82; % LowLambda
  ParamStore(10*cm_num, 6)= 4.46; % CapGamma
  ParamStore(10*cm_num, 7)= 6.25; % LowGamma
  ParamStore(10*cm_num, 8)= 6.28; % LowSigma_c
  ParamStore(10*cm_num, 9)= 13.0; % LowSigma_r
  ParamStore(10*cm_num, 10)= 49.8; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 9; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -18.8; % Delta_LowK
  ParamStore(10*cm_num, 14)= 0; %nlos
  ParamStore(10*cm_num, 15)= 0; % TSV flag
  ParamStore(10*cm_num, 16)= 1; % SynNLOS
cm_num=2.2; % Residential NLOS
  ParamStore(10*cm_num, 1)= 1.53; % n
  ParamStore(10*cm_num, 2)= 75.1; % PLo
  ParamStore(10*cm_num, 3)= 1.5; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1/5.15; % CapLambda
  ParamStore(10*cm_num, 5)= 1/1.11; % LowLambda
  ParamStore(10*cm_num, 6)= 8.98; % CapGamma
  ParamStore(10*cm_num, 7)= 9.17; % LowGamma
  ParamStore(10*cm_num, 8)= 6.63; % LowSigma_c
  ParamStore(10*cm_num, 9)= 9.83; % LowSigma_r
  ParamStore(10*cm_num, 10)= 119; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 11; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -17.4; % Delta_LowK
  ParamStore(10*cm_num, 14)= 0; %nlos
  ParamStore(10*cm_num, 15)= 0; % TSV flag
  ParamStore(10*cm_num, 16)= 1; % SynNLOS
cm_num=2.3; % Residential NLOS
  ParamStore(10*cm_num, 1)= 1.53; % n
  ParamStore(10*cm_num, 2)= 75.1; % PLo
  ParamStore(10*cm_num, 3)= 1.5; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1/6.94; % CapLambda
  ParamStore(10*cm_num, 5)= 1/0.856; % LowLambda
  ParamStore(10*cm_num, 6)= 21.5; % CapGamma
  ParamStore(10*cm_num, 7)= 4.35; % LowGamma
  ParamStore(10*cm_num, 8)= 3.71; % LowSigma_c
  ParamStore(10*cm_num, 9)= 7.31; % LowSigma_r
  ParamStore(10*cm_num, 10)= 46.2; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 8; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -11.9; % Delta_LowK
  ParamStore(10*cm_num, 14)= 0; %nlos
  ParamStore(10*cm_num, 15)= 0; % TSV flag
  ParamStore(10*cm_num, 16)= 1; % SynNLOS
cm_num=2.4; % Residential NLOS
  ParamStore(10*cm_num, 1)= 1.53; % n
  ParamStore(10*cm_num, 2)= 75.1; % PLo
  ParamStore(10*cm_num, 3)= 1.5; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1/22.2; % CapLambda
  ParamStore(10*cm_num, 5)= 1/1.08; % LowLambda
  ParamStore(10*cm_num, 6)= 12.6; % CapGamma
  ParamStore(10*cm_num, 7)= 4.98; % LowGamma
  ParamStore(10*cm_num, 8)= 7.34; % LowSigma_c
  ParamStore(10*cm_num, 9)= 6.11; % LowSigma_r
  ParamStore(10*cm_num, 10)= 107; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 4; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -4.60; % Delta_LowK
  ParamStore(10*cm_num, 14)= 0; %nlos
  ParamStore(10*cm_num, 15)= 0; % TSV flag
  ParamStore(10*cm_num, 16)= 1; % SynNLOS
cm_num=2.5; % Residential NLOS
  ParamStore(10*cm_num, 1)= 1.53; % n
  ParamStore(10*cm_num, 2)= 75.1; % PLo
  ParamStore(10*cm_num, 3)= 1.5; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1/4.76; % CapLambda
  ParamStore(10*cm_num, 5)= 1/1.30; % LowLambda
  ParamStore(10*cm_num, 6)= 4.19; % CapGamma
  ParamStore(10*cm_num, 7)= 1.07; % LowGamma
  ParamStore(10*cm_num, 8)= 1.54; % LowSigma_c
  ParamStore(10*cm_num, 9)= 1.26; % LowSigma_r
  ParamStore(10*cm_num, 10)= 8.32; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 4; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -10; % Delta_LowK
  ParamStore(10*cm_num, 14)= 0; %nlos
  ParamStore(10*cm_num, 15)= 0; % TSV flag
  ParamStore(10*cm_num, 16)= 1; % SynNLOS
cm_num=3.1; % Office LOS
  ParamStore(10*cm_num, 1)= 1.16; % n
  ParamStore(10*cm_num, 2)= 84.6; % PLo
  ParamStore(10*cm_num, 3)= 5.4; % LowSigma_s
  ParamStore(10*cm_num, 4)= 0.041; % CapLambda
  ParamStore(10*cm_num, 5)= 0.971; % LowLambda
  ParamStore(10*cm_num, 6)= 49.8; % CapGamma
  ParamStore(10*cm_num, 7)= 45.2; % LowGamma
  ParamStore(10*cm_num, 8)= 6.6; % LowSigma_c
  ParamStore(10*cm_num, 9)= 11.3; % LowSigma_r
  ParamStore(10*cm_num, 10)= 102; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 6; % L_mean
  ParamStore(10*cm_num, 12)= 27.2; % Delta_CapK
  ParamStore(10*cm_num, 13)= -21.9; % Delta_LowK
  ParamStore(10*cm_num, 14)= 0; %nlos
  ParamStore(10*cm_num, 15)= 1; % TSV flag
  ParamStore(10*cm_num, 16)= 0; % SynNLOS
cm_num=3.2; % Office LOS
  ParamStore(10*cm_num, 1)= 1.16; % n
  ParamStore(10*cm_num, 2)= 84.6; % PLo
  ParamStore(10*cm_num, 3)= 5.4; % LowSigma_s
  ParamStore(10*cm_num, 4)= 0.027; % CapLambda
  ParamStore(10*cm_num, 5)= 0.293; % LowLambda
  ParamStore(10*cm_num, 6)= 38.8; % CapGamma
  ParamStore(10*cm_num, 7)= 64.9; % LowGamma
  ParamStore(10*cm_num, 8)= 8.04; % LowSigma_c
  ParamStore(10*cm_num, 9)= 7.95; % LowSigma_r
  ParamStore(10*cm_num, 10)= 66.4; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 5; % L_mean
  ParamStore(10*cm_num, 12)= 22.8; % Delta_CapK
  ParamStore(10*cm_num, 13)= -11.4; % Delta_LowK
  ParamStore(10*cm_num, 14)= 0; %nlos
  ParamStore(10*cm_num, 15)= 1; % TSV flag
  ParamStore(10*cm_num, 16)= 0; % SynNLOS
cm_num=4.1; % Office NLOS
  ParamStore(10*cm_num, 1)= 3.74; % n
  ParamStore(10*cm_num, 2)= 56.1; % PLo
  ParamStore(10*cm_num, 3)= 8.6; % LowSigma_s
  ParamStore(10*cm_num, 4)= 0.032; % CapLambda
  ParamStore(10*cm_num, 5)= 3.45; % LowLambda
  ParamStore(10*cm_num, 6)= 109.2; % CapGamma
  ParamStore(10*cm_num, 7)= 67.9; % LowGamma
  ParamStore(10*cm_num, 8)= 3.24; % LowSigma_c
  ParamStore(10*cm_num, 9)= 5.54; % LowSigma_r
  ParamStore(10*cm_num, 10)= 60.2; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 5; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -19; % Delta_LowK
  ParamStore(10*cm_num, 14)= 1; %nlos
  ParamStore(10*cm_num, 15)= 0; % TSV flag
  ParamStore(10*cm_num, 16)= 0; % SynNLOS
cm_num=4.2; % Office NLOS
  ParamStore(10*cm_num, 1)= 3.74; % n
  ParamStore(10*cm_num, 2)= 56.1; % PLo
  ParamStore(10*cm_num, 3)= 8.6; % LowSigma_s
  ParamStore(10*cm_num, 4)= 0.028; % CapLambda
  ParamStore(10*cm_num, 5)= 0.76; % LowLambda
  ParamStore(10*cm_num, 6)= 134; % CapGamma
  ParamStore(10*cm_num, 7)= 59; % LowGamma
  ParamStore(10*cm_num, 8)= 4.37; % LowSigma_c
  ParamStore(10*cm_num, 9)= 6.66; % LowSigma_r
  ParamStore(10*cm_num, 10)= 22.2; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 5; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -19.2; % Delta_LowK
  ParamStore(10*cm_num, 14)= 1; %nlos
  ParamStore(10*cm_num, 15)= 0; % TSV flag
  ParamStore(10*cm_num, 16)= 0; % SynNLOS
cm_num=4.3; % Office NLOS
  ParamStore(10*cm_num, 1)= 3.74; % n
  ParamStore(10*cm_num, 2)= 56.1; % PLo
  ParamStore(10*cm_num, 3)= 8.6; % LowSigma_s
  ParamStore(10*cm_num, 4)= 0.07; % CapLambda
  ParamStore(10*cm_num, 5)= 1.88; % LowLambda
  ParamStore(10*cm_num, 6)= 19.44; % CapGamma
  ParamStore(10*cm_num, 7)= 0.42; % LowGamma
  ParamStore(10*cm_num, 8)= 1.82; % LowSigma_c
  ParamStore(10*cm_num, 9)= 1.88; % LowSigma_r
  ParamStore(10*cm_num, 10)= 9.1; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 6; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -10; % Delta_LowK
  ParamStore(10*cm_num, 14)= 1; %nlos
  ParamStore(10*cm_num, 15)= 0; % TSV flag
  ParamStore(10*cm_num, 16)= 0; % SynNLOS
cm_num=5; % Library LOS
  ParamStore(cm_num, 1)= 3; % n
  ParamStore(cm_num, 2)= 50; % PLo
  ParamStore(cm_num, 3)= 10; % LowSigma_s
  ParamStore(cm_num, 4)= 0.25; % CapLambda
  ParamStore(cm_num, 5)= 4.0; % LowLambda
  ParamStore(cm_num, 6)= 12; % CapGamma
  ParamStore(cm_num, 7)= 7.0; % LowGamma
  ParamStore(cm_num, 8)= 5.0; % LowSigma_c
  ParamStore(cm_num, 9)= 6.0; % LowSigma_r
  ParamStore(cm_num, 10)= 10.0; % LowSigma_phi
  ParamStore(cm_num, 11)= 17; % L_mean
  ParamStore(cm_num, 12)= 8; % Delta_CapK
  ParamStore(cm_num, 13)= -13; % Delta_LowK
  ParamStore(cm_num, 14)= 0; %nlos
  ParamStore(cm_num, 15)= 0; % TSV flag
  ParamStore(cm_num, 16)= 0; % SynNLOS
cm_num=6; % Library NLOS
  ParamStore(cm_num, 1)= 3; % n
  ParamStore(cm_num, 2)= 50; % PLo
  ParamStore(cm_num, 3)= 10; % LowSigma_s
  ParamStore(cm_num, 4)= 0.25; % CapLambda
  ParamStore(cm_num, 5)= 4.0; % LowLambda
  ParamStore(cm_num, 6)= 12; % CapGamma
  ParamStore(cm_num, 7)= 7.0; % LowGamma
  ParamStore(cm_num, 8)= 5.0; % LowSigma_c
  ParamStore(cm_num, 9)= 6.0; % LowSigma_r
  ParamStore(cm_num, 10)= 10.0; % LowSigma_phi
  ParamStore(cm_num, 11)= 17; % L_mean
  ParamStore(cm_num, 12)= 8; % Delta_CapK
  ParamStore(cm_num, 13)= -13; % Delta_LowK
  ParamStore(cm_num, 14)= 0; %nlos
  ParamStore(cm_num, 15)= 0; % TSV flag
  ParamStore(cm_num, 16)= 1; % SynNLOS
cm_num=7; % Circular Polarized Office LOS ... not supported in 802.15.3c
  ParamStore(cm_num, 1)= 3; % n
  ParamStore(cm_num, 2)= 50; % PLo
  ParamStore(cm_num, 3)= 10; % LowSigma_s
  ParamStore(cm_num, 4)= 1/2.11; % CapLambda
  ParamStore(cm_num, 5)= 1/2.11; % LowLambda
  ParamStore(cm_num, 6)= 3.08; % CapGamma
  ParamStore(cm_num, 7)= 3.08; % LowGamma
  ParamStore(cm_num, 8)= 3.82; % LowSigma_c
  ParamStore(cm_num, 9)= 3.82; % LowSigma_r
  ParamStore(cm_num, 10)= 80; % LowSigma_phi
  ParamStore(cm_num, 11)= 0; % L_mean
  ParamStore(cm_num, 12)= 10; % Delta_CapK
  ParamStore(cm_num, 13)= -10; % Delta_LowK
  ParamStore(cm_num, 14)= 0; %nlos
  ParamStore(cm_num, 15)= 0; % TSV flag
  ParamStore(cm_num, 16)= 0; % SynNLOS
cm_num=8; % Circular Polarized Residential LOS ... not supported in 802.15.3c
  ParamStore(cm_num, 1)= 3; % n
  ParamStore(cm_num, 2)= 50; % PLo
  ParamStore(cm_num, 3)= 10; % LowSigma_s
  ParamStore(cm_num, 4)= 1/3.24; % CapLambda
  ParamStore(cm_num, 5)= 1/3.24; % LowLambda
  ParamStore(cm_num, 6)= 6.06; % CapGamma
  ParamStore(cm_num, 7)= 6.06; % LowGamma
  ParamStore(cm_num, 8)= 6.77; % LowSigma_c
  ParamStore(cm_num, 9)= 6.77; % LowSigma_r
  ParamStore(cm_num, 10)= 74; % LowSigma_phi
  ParamStore(cm_num, 11)= 0; % L_mean
  ParamStore(cm_num, 12)= 10; % Delta_CapK
  ParamStore(cm_num, 13)= -10; % Delta_LowK
  ParamStore(cm_num, 14)= 0; %nlos
  ParamStore(cm_num, 15)= 0; % TSV flag
  ParamStore(cm_num, 16)= 0; % SynNLOS
cm_num=9.1; % Desktop LOS
  ParamStore(10*cm_num, 1)= 3; % n
  ParamStore(10*cm_num, 2)= 50; % PLo
  ParamStore(10*cm_num, 3)= 10; % LowSigma_s
  ParamStore(10*cm_num, 4)= 0.037; % CapLambda
  ParamStore(10*cm_num, 5)= 0.641; % LowLambda
  ParamStore(10*cm_num, 6)= 21.1; % CapGamma
  ParamStore(10*cm_num, 7)= 8.85; % LowGamma
  ParamStore(10*cm_num, 8)= 3.0; % LowSigma_c
  ParamStore(10*cm_num, 9)= 7.7; % LowSigma_r
  ParamStore(10*cm_num, 10)= 34.6; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 3; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -10; % Delta_LowK
  ParamStore(10*cm_num, 14)= 0; %nlos
  ParamStore(10*cm_num, 15)= 1; % TSV flag
  ParamStore(10*cm_num, 16)= 0; % SynNLOS
cm_num=9.2; % Desktop LOS
  ParamStore(10*cm_num, 1)= 3; % n
  ParamStore(10*cm_num, 2)= 50; % PLo
  ParamStore(10*cm_num, 3)= 10; % LowSigma_s
  ParamStore(10*cm_num, 4)= 0.047; % CapLambda
  ParamStore(10*cm_num, 5)= 0.373; % LowLambda
  ParamStore(10*cm_num, 6)= 22.3; % CapGamma
  ParamStore(10*cm_num, 7)= 17.2; % LowGamma
  ParamStore(10*cm_num, 8)= 7.27; % LowSigma_c
  ParamStore(10*cm_num, 9)= 4.42; % LowSigma_r
  ParamStore(10*cm_num, 10)= 38.1; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 3; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -10; % Delta_LowK
  ParamStore(10*cm_num, 14)= 0; %nlos
  ParamStore(10*cm_num, 15)= 1; % TSV flag
  ParamStore(10*cm_num, 16)= 0; % SynNLOS
cm_num=9.3; % Desktop LOS
  ParamStore(10*cm_num, 1)= 3; % n
  ParamStore(10*cm_num, 2)= 50; % PLo
  ParamStore(10*cm_num, 3)= 10; % LowSigma_s
  ParamStore(10*cm_num, 4)= 1.72; % CapLambda
  ParamStore(10*cm_num, 5)= 3.14; % LowLambda
  ParamStore(10*cm_num, 6)= 4.01; % CapGamma
  ParamStore(10*cm_num, 7)= 0.58; % LowGamma
  ParamStore(10*cm_num, 8)= 2.7; % LowSigma_c
  ParamStore(10*cm_num, 9)= 1.9; % LowSigma_r
  ParamStore(10*cm_num, 10)= 14; % LowSigma_phi
  ParamStore(10*cm_num, 11)= 14; % L_mean
  ParamStore(10*cm_num, 12)= 10; % Delta_CapK
  ParamStore(10*cm_num, 13)= -10; % Delta_LowK
  ParamStore(10*cm_num, 14)= 0; %nlos
  ParamStore(10*cm_num, 15)= 1; % TSV flag
  ParamStore(10*cm_num, 16)= 0; % SynNLOS
cm_num=10; % Corridor LOS
  ParamStore(cm_num, 1)= 2.29; % n
  ParamStore(cm_num, 2)= 69.7; % PLo
  ParamStore(cm_num, 3)= 8.4; % LowSigma_s
  ParamStore(cm_num, 4)= 1.00; % CapLambda
  ParamStore(cm_num, 5)= 1.00; % LowLambda
  ParamStore(cm_num, 6)= 1.00; % CapGamma
  ParamStore(cm_num, 7)= 7.00; % LowGamma
  ParamStore(cm_num, 8)= 1.00; % LowSigma_c
  ParamStore(cm_num, 9)= 0.00; % LowSigma_r
  ParamStore(cm_num, 10)= 14.5; % LowSigma_phi
  ParamStore(cm_num, 11)= 1; % L_mean
  ParamStore(cm_num, 12)= 10; % Delta_CapK
  ParamStore(cm_num, 13)= -10; % Delta_LowK
  ParamStore(cm_num, 14)= 0; %nlos
  ParamStore(cm_num, 15)= 0; % TSV flag
  ParamStore(cm_num, 16)= 0; % SynNLOS
  
clear cm_num
  
save SvStore; % save all the S-V parameters for all channel models
    
disp(' ')
disp('SV Parameters Loaded')
disp(' ')

return
