%----------------------------------------------------------------------------------
%
% Description :
% This function M-file outputs electric strength according to angle of arrival (AOA).
% The antenna patterns contributed in TG3C can be used:
% Reference antenna model (IEEE 15-06-0427-04-003c)
% Gaussian-distributed antenna model (IEEE 15-06-0195-03-003c)
%
% Programmed by R. Funada, K. Iigusa, and H. Harada (18-Dec-2006)
%----------------------------------------------------------------------------------

function g = calc_ant_gain_pre_fin_rev3(ant_type, hpang, fai)

% Arguments
% ant_type: Antenna pattern
%	1: Reference antenna model (15-06-0427-04-003c)
%	2: Gaussian-distributed antenna model
% hpang : Half-power angle in deg
% fai : Angle of arrival in deg

% Output value
% g		: Electric strength (True value)
switch ant_type
	case 1 %Reference antenna model
		%IEEE 802.15-06/474r0
		theta_ml=2.6*hpang;
		hpangrad=hpang*pi/180;
		G0 = 10*log10((1.6162./sin(hpangrad/2))^2);
		if abs(fai)<=theta_ml/2
			G = G0 - 3.01 * (2*abs(fai)./hpang).^2;
		else
			G = -0.4111.*log(hpangrad)-10.597;
		end
		g0=G-G0;
		g = 10.^(g0/20);
	case 2 %Gaussian-distributed antenna model
		alfa = 4*log(2)./(hpang*pi/180).^2;
		g	= sqrt(exp(-alfa.*abs(fai./180*pi).^2));
	otherwise
		error('Antenna type error')
end