%Main Script M-file
%----------------------------------------------------------------------------------
%
% Description:
% This function generates impulse responses on the basis of TSV model
% IEEE802.15.4a distribution code was modified by
% H. Harada, R. Funada, H. Sawada, C-H Choi, Y. Shoji, and S. Kato
%
% Program tips
%	Tab size: 4
%	Indent size:4
%----------------------------------------------------------------------------------
% Comment:

%***************************** Preparation Part ****************************

clear variables
close all
randn_seed_ch=12;
rand_seed_ch=12;
randn('state',randn_seed_ch);    % initialize state of function for repeatability
rand('state',rand_seed_ch);     % initialize state of function for repeatability

%*************************** Determine Parameters **************************
disp(' ')
disp('******************* TSV channel model Parameter setup *******************')
disp('Channel model index: ')
disp('		Scenario	Environment	Engine')
disp('CM1:	LOS			Residential	TSV engine')
disp('CM2:	NLOS		Residential	TSV engine (LOS component exstraction mode)')
disp('CM3:	LOS			Office		TSV engine')
disp('CM4:	NLOS		Office		TSV engine')
disp('CM5:	LOS			Library		SV engine')
disp('CM6:	NLOS		Library		SV engine')
disp('CM7:	LOS			Conference	SV engine')
disp('CM8:	NLOS		Conference	SV engine')
disp('CM9:	LOS			Desktop		TSV engine')
disp('CM10:	NLOS		Corridor	SV engine')
channel_num=input('\nSelect channel model index you want to generate: CM');

disp(' ')
switch channel_num
	case 1
		disp('-------- LOS residential channels will be generated with TSV engine -------')
		disp('Measured Antenna pattern configulation')
		disp('CM1.1: Tx : 360 deg, Rx : 15 deg')
		disp('CM1.2: Tx : 60  deg, Rx : 15 deg')
		disp('CM1.3: Tx : 30  deg, Rx : 15 deg')
		disp('CM1.4: Tx : 15  deg, Rx : 15 deg')
	case 2
		disp('------- NLOS residential channels will be generated with TSV engine -------')
		disp('LOS component exstraction mode')
		disp('Measured Antenna pattern configulation')
		disp('CM2.1: Tx : 360 deg, Rx : 15 deg')
		disp('CM2.2: Tx : 60  deg, Rx : 15 deg')
		disp('CM2.3: Tx : 30  deg, Rx : 15 deg')
		disp('CM2.4: Tx : 15  deg, Rx : 15 deg')
	case 3
		disp('---------- LOS office channels will be generated with TSV engine ----------')
		disp('Measured Antenna pattern configulation')
		disp('CM3.1: Tx : 30 deg, Rx : 30 deg')
		disp('CM3.2: Tx : 60 deg, Rx : 60 deg')
	case 4
		disp('---------- NLOS office channels will be generated with TSV engine ---------')
		disp('Measured Antenna pattern configulation')
		disp('CM4.1: Tx : 30 deg, Rx : 30 deg')
		disp('CM4.2: Tx : 60 deg, Rx : 60 deg')
	case 9
		disp('---------- LOS desktop channels will be generated with TSV engine ---------')
		disp('Measured Antenna pattern configulation')
		disp('CM9.1: Tx : 30 deg, Rx : 30 deg')
		disp('CM9.2: Tx : 60 deg, Rx : 60 deg')
	otherwise
		disp('Since a channel model based on SV engine was selected, exit from this Matlab code ')
		return
end
disp('NOTICE: Rx antenna beam-width can be changed for channel realizations, whereas Tx antenna beam-width is fixed, ')
channel_num2=input(strcat('\nSelect channel model you want to generate: CM',num2str(channel_num),'.'));
cm_num=10*channel_num+channel_num2;

disp(' ')
disp('Input Rx beam-width to be simulated in deg from 0 to 360 deg')
disp('if skipped, this variable is set to 30 deg (default value)')
rx_hpang=input('->');
if isempty(rx_hpang) == 1
	disp('Default antenna beam-width (30 deg) is set')
	rx_hpang = 30;
end

disp(' ')
disp('Types of antenna pattern: ')
disp('ANT1: Reference antenna model')
disp('ANT2: Gaussian-distributed antenna model')
ant_type=input('\nSet antenna pattern: ANT');

fc = input ('Set center carrier frequency in GHz :');
fc=fc*1e9;
num_channels = input('Set number of channel realizations ->');
ts=input('Set time resolution in ns :');

disp(' ')
disp('************************ How to save generated IRs ************************')
MAT_flag = input('Save continuous IRs and some parameters to MAT file? YES:1 NO:0  ->');
%
MAT_flag2 = input('Save discrete IRs and some parameters to MAT file? YES:1 NO:0  ->');

disp(' ')
disp('************************* How to display figures *************************')
disp_flg = input('Display antenna pattern used for the channel realizations? YES:1 NO:0 ->');
disp_flg1 = input('Display power delay profile? YES:1 NO:0 ->');
if disp_flg1 ==1
	disp_flg2 = input('		How to display: Each channel realization:1 All channel realizations:0 ->');
end
disp_flg3 = input('Display power delay profile with angle-of-arrival? YES:1 NO:0 ->');

%************************* Load Channel Parameters *************************
[adist, nlos, los_beta_flg, Omega0, smallk, Lmean, Lam, lambda, Gam, gamma,...
	std_ln_1,std_ln_2, sigma_fai, L_pl, tx_hpang, rx_hpang0]= tg3c_tsv_params_pre_fin_rev3(cm_num, fc);

%************************* Display Model Parameters ************************
disp(' ')
fprintf(1,['***************************** Model Parameters ****************************\n' ...
	'  Channel model number = CM%d.%d\n' ...
	'  Number of channel realizations = %d\n' ...
	'  Assuming distance between Tx and Rx = %d[m]\n' ...
	'  TSV model flag = %d, LOS component pathloss = %.4f[dB]\n' ...
	'  Lmean = %d, Omega0  = %5.5f[dB], smallk= %5.5f, sigma_fai = %.4f[deg]\n' ...
	'  1/Lam = %.4f, 1/lambda = %.4f, Gam = %.4f, gamma = %.4f\n' ...
	'  std_ln_1 = %.4f, std_ln_2 = %.4f\n'...
	'  Antenna pattern type = %d\n' ...
	'  Measured antenna pattern:\n'...
	'  Beam-width of Measured Tx antenna = %2d[deg]\n'...
	'  Beam-width of Measured Rx antenna = %2d[deg]\n' ...
	'  Beam-width of Simulated Rx antenna = %2d[deg]\n'...
	'***************************************************************************\n'],...
	channel_num,channel_num2, num_channels, adist, los_beta_flg, L_pl, Lmean, Omega0, smallk,...
	sigma_fai, 1/Lam, 1/lambda, Gam, gamma, std_ln_1, std_ln_2,...
	ant_type,tx_hpang, rx_hpang0,rx_hpang);

%******************* Continuous Channel Impulse Response *******************
% Arguments : see tg3c_tsv_params_pre_fin.m
% Output:
%	beta	: impulse response of the LOS component
%	h_ct	: continuous impulse responses of SV clusters
%	aoa_ct  : angle of arrival of h_ct
%	t_ct	: time of arrival of h_ct
%	t0		: arrival time of the first ray of the first SV cluster
%	np		: number of paths of SV clusters

[beta,h_ct,aoa_ct, t_ct,t0,np,sv_num] = tg3c_tsv_ct_pre_fin_rev4(...
	nlos, num_channels,...									% Channel params
	adist, fc, los_beta_flg, L_pl, ...					% T-S-V model params
	Lam, lambda, Gam, gamma, std_ln_1, std_ln_2, Lmean, ...	% SV model params
	Omega0, smallk, sigma_fai,...							% SV model params regarding TSV model
	tx_hpang, rx_hpang, ant_type);							% Antenna pattern

%******************* Save Some Parameters to the MAT file******************
if MAT_flag == 1
	MAT_NAME=strcat('tsv_cIR_cm_num',num2str(cm_num),'_num_channels',num2str(num_channels),...
		'_at',num2str(ant_type));
	save(MAT_NAME,'cm_num','num_channels','ant_type','h_ct','t_ct','aoa_ct',...
		'rand_seed_ch','randn_seed_ch');
	fprintf('\nMAT file including continuous IRs were successfully created\n\n')
end

%**************** Converte to Continuous IRs to Descrete IRs ***************
[hN,N] = tg3c_sv_cnvrt_ct( h_ct, t_ct, np, num_channels, ts);

% If we wanted complex baseband model or to impose some filtering function,
% this would be a good place to do it
if N > 1,
	h = resample(hN, 1, N);  % decimate the columns of hN by factor N
else
	h = hN;
end
% correct for 1/N scaling imposed by decimation

h = h * N;

%**************** End of channel impulse response generation ***************

%******************* Save Some Parameters to the MAT file ******************

if MAT_flag2 == 1
	TS = num2str(ts*1e5);
	MAT_NAME2=strcat('tsv_dIR_cm_num',num2str(cm_num),'_num_channels',num2str(num_channels),...
		'_at',num2str(ant_type),'_ts',TS(1:3));
	save(MAT_NAME2,'cm_num','num_channels','ant_type','ts','rand_seed_ch','randn_seed_ch');
	fprintf('\nMAT file including continuous IRs were successfully created\n\n')
end

%******************** Compute Some of Highlight Results ********************

% Calsulate the median of beta and maximum beta in dB
h_len = size(h,1);
channel_energy = sum(abs(h).^2);

t = (0:(h_len-1)) * ts;  % for use in computing excess & RMS delays
excess_delay = zeros(1,num_channels);
RMS_delay = zeros(1,num_channels);
num_sig_paths = zeros(1,num_channels);
num_sig_e_paths = zeros(1,num_channels);
K2=zeros(1,num_channels);

if los_beta_flg ~= -1
	for k=1:num_channels
		% determine excess delay and RMS delay
		sq_h = abs(h(:,k)).^2 / channel_energy(k);
		t_norm = t - t0(k);  % remove the randomized arrival time of first cluster
		excess_delay(k) = t_norm * sq_h;
		RMS_delay(k) = sqrt( ((t_norm-excess_delay(k)).^2) * sq_h );

		K2(k)= 10*log10(abs(h(1,k)).^2./sum(abs(h(2:end,k).^2)));
	end
	fprintf(1,['\nAverage RMS_delay is %1.3f [ns] \n',...
		'Maximum RMS delay is %1.3f [ns] \n',...
		'Miminum RMS delay is %1.3f [ns] \n',...
		'Average Racian factor is %1.3f [dB]\n',...
		'Maximum Racian factor is %1.3f [dB] \n',...
		'Miminum Racian factor is %1.3f [dB] \n'],...
		mean(RMS_delay),max(RMS_delay),min(RMS_delay),mean(K2),max(K2),min(K2))
end

if disp_flg == 1
	ant_ptn(ant_type,tx_hpang,1,'Tx antenna pattern');
	ant_ptn(ant_type,rx_hpang,2,'Simulated Rx antenna pattern')
end

if disp_flg1 == 1
	L_pl0		= -20*log10(4*pi/(3e8/fc));
	if disp_flg2 ==0
		figure(10);
		set(gca,'FontName','Arial')
		set(gca,'FontSize',12)

		h_len = size(h,1);
		t = (0:(h_len-1)) * ts;  % for use in computing excess & RMS delays
		plot(t,20*log10(abs(h))+L_pl0,'-x');
		grid on;
		axis([0 t(end) -60+L_pl0 10+L_pl0])
		xlabel('Time of arrival[ns]')
		ylabel('Relative power [dB]')
		title('Power delay profile')
	else
		h_len = size(h,1);
		t = (0:(h_len-1)) * ts;  % for use in computing excess & RMS delays
		figure(10)
		set(gca,'FontName','Arial')
		set(gca,'FontSize',12)
		xlabel('Time of arrival[ns]')
		ylabel('Relative power [dB]')
		title('Power delay profile')
		grid on;
		hold on
		plot_color=['b-x'; 'r-x'; 'g-x'; 'y-x'; 'm-x';...
			'c-x'; 'g-x';'b-x'; 'r-x'; 'g-x'; 'y-x'; 'm-x'; 'c-x'; 'g-x'];
		for ij=1:num_channels
			COLOR0=rem(ij-1,7)+1;
			plot(t,20*log10(abs(h(:,ij)))+L_pl0,plot_color(COLOR0,:));
			axis([0 t(end) -60+L_pl0 10+L_pl0])
			hold on;
			disp('Display the next channel realization? Prease enter key')
			skid=input('To skip this display, enter "1"');
			if skid==1
				disp('Stop displaying')
				break
			end
		end
	end
end

if disp_flg3 == 1
	plot_color=['b-x'; 'r-x'; 'g-x'; 'y-x'; 'm-x'; 'c-x'; 'g-x'];
	for ij=1:num_channels
		figure(20);
		set(gca,'FontName','Arial')
		set(gca,'FontSize',12)
		xlabel('Time of arrival [ns])')
		ylabel('Angle of arrival [deg]')
		zlabel('20*log10(amplitude)+100 [dB]')
		title('Power delay profile')
		hold on

		COLOR0=rem(ij-1,7)+1;
		sv_power=20*log10(abs(h_ct(1:np(ij),ij)))+100;
		ij2=find(sv_power>0);
		sv_num2=sv_num(ij2,ij);
		aoa_ct2=aoa_ct(ij2,ij);
		h_ct2=h_ct(ij2,ij);
		t_ct2=t_ct(ij2,ij);

		for L=1:Lmean
			COLOR0=rem(L-1,7)+1;
			to=find(sv_num2==L);
			stem3(t_ct2(to),angle(aoa_ct2(to))*180/pi,20*log10(abs(h_ct2(to)))+100,plot_color(COLOR0,:));
			hold on
		end
		stem3(0,0,20*log10(h(1,ij))+100,'k-o');
		view([-40 50])
		grid on;
		disp('Display the next channel realization? Prease enter key')
		skid=input('To skip this display, enter "1"');
		close(20)
		if skid==1
			disp('Stop displaying')
			break
		end
	end
end
